PCB Environment: dsn::Image Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
dsn::Image Struct Reference

## Public Member Functions
std::string | str () const

## Data Fields
std::string | name
std::vector< Pin > | pins
dsn::Shape | footprint
std::vector< Placement * > | placements

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/DSN.hpp